@@ -1,6 +1,6 @@
 /* gom, Gom is nOt yet another (Audio) Mixer.
  *
- * Copyright (C) 1996-2004  Stephan A Suerken <absurd@olurdix.de>
+ * Copyright (C) 1996-2004  Stephan Sürken <absurd@olurdix.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -48,7 +48,7 @@
 enum gom_info_types {GOM_INFO_ERROR=-1, GOM_INFO_QUIET, GOM_INFO_NORMAL, GOM_INFO_VERBOSE, GOM_INFO_DEBUG};
 
 /* shown errors count */
-int gom_info_errors;
+extern int gom_info_errors;
 
 /*
  * FUNCTION PROTOTYPES
